# Bowser

Bowser is an intuitive and powerful web automation toolkit built on top of Selenium. It features stealth techniques, deep element searches (across shadow DOMs and iframes), and customizable hooks to make website automation simple and robust.

## Installation

```bash
pip install bowser
